# MaxMind Geolocation DXL Service
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

## Overview

The MaxMind DXL Python service exposes Host/IP Geolocation lookups in a MaxMind [GeoLite2](http://dev.maxmind.com/geoip/geoip2/geolite2/) or
[GeoIP2](https://www.maxmind.com/en/geoip2-databases) database via the Data Exchange Layer (DXL) fabric.

## Documentation

See the [Wiki](https://github.com/opendxl/opendxl-maxmind-service-python/wiki) for an overview of the
MaxMind DXL Python service and usage examples.

See the [MaxMind API DXL Python service documentation](https://opendxl.github.io/opendxl-maxmind-service-python/pydoc) for
installation instructions, API documentation, and usage examples.

## Installation

To start using the MaxMind DXL Python Service:

* Download the [Latest Release](https://github.com/opendxl/opendxl-maxmind-service-python/releases/latest)
* Extract the release .zip file
* View the `README.html` file located at the root of the extracted files.
  * The `README` links to the documentation which includes installation instructions and usage examples.

## Docker Support

A pre-built Docker image can be used as an alternative to installing a Python environment with the
modules required for the MaxMind DXL service.

See the [Docker Support Documentation](https://opendxl.github.io/opendxl-maxmind-service-python/pydoc/docker.html) for details.

## Bugs and Feedback

For bugs, questions and discussions please use the [GitHub Issues](https://github.com/opendxl/opendxl-maxmind-service-python/issues).

## LICENSE

Copyright 2017 McAfee LLC

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
